@@ -177,19 +177,19 @@ function search_client($sn, $subnet, $hoststr, $post)
             /* פʤ */
             if ($post["duidsearch"] == "same"){
                 $formed_duid = check_macaddr($post["duid"]);
-                if ($formed_duid != strtolower($duid)) {
+                if ($formed_duid != $duid) {
                     continue;
                 }
             /* ޤʤ */
             } else {
-                if (strpos(strtolower($duid), strtolower($post["duid"])) === FALSE) {
+                if (strpos($duid, strtolower($post["duid"])) === FALSE) {
                     continue;
                 }
             }
         }
         /* IPɥ쥹뤫 */
         if ($post["ipaddr"] != "") {
-            if (strpos(strtolower($ip), strtolower($post["ipaddr"])) === FALSE) {
+            if (strpos($ip, $post["ipaddr"]) === FALSE) {
                 continue;
             }
         }
@@ -515,7 +515,7 @@ if (empty($_POST["hostsearch"])) {
 }
 $tag["<<SEARCHHOST>>"] = "$in_host";
 $tag["<<SEARCHDUID>>"] = "$in_duid";
-$tag["<<SEARCHIP>>"] = "$in_ip";
+$tag["<<SEARCHIPV6>>"] = "$in_ip";
 /* IP߽κɽ */
 client_re_display($in_case, $select_host, $select_duid);
 /*   */
